"use strict";
/*
 * Copyright (c) 2022.
 * Author Peter Placzek (tada5hi)
 * For the full copyright and license information,
 * view the LICENSE file that was distributed with this source code.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyToken = void 0;
const domains_1 = require("@typescript-auth/domains");
function verifyToken(context) {
    return __awaiter(this, void 0, void 0, function* () {
        let data;
        if (context.tokenCache) {
            data = yield context.tokenCache.get(context.token);
        }
        if (!data) {
            let payload;
            try {
                payload = yield context.tokenAPIClient.verify(context.token);
            }
            catch (e) {
                throw new domains_1.TokenError({
                    statusCode: e.response.status,
                    code: e.response.data.code,
                    message: e.response.data.message,
                });
            }
            let secondsDiff = payload.payload.expire_time - (new Date().getTime() / 1000);
            secondsDiff = parseInt(secondsDiff.toString(), 10);
            if (secondsDiff <= 0) {
                throw domains_1.TokenError.expired();
            }
            if (context.tokenCache) {
                yield context.tokenCache.set(context.token, payload, { seconds: secondsDiff });
            }
            data = payload;
        }
        return data;
    });
}
exports.verifyToken = verifyToken;
//# sourceMappingURL=token-verify.js.map